==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialogprintproject.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGPRINTPROJECT_H
#define INCLUDED_DIALOGPRINTPROJECT_H


#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "configuration.h"


class PrintProjectDialog
{
public:
  PrintProjectDialog (Scripture *scripture_in, Configuration * configuration_in);
  virtual ~PrintProjectDialog ();
  virtual int run ();
protected:
  GtkWidget *printprojectdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *hbox1;
  GtkWidget *label1;
  GtkWidget *label_portion;
  GtkWidget *vseparator1;
  GtkWidget *label3;
  GtkWidget *label_order;
  GtkWidget *vseparator2;
  GtkWidget *button_portion_order;
  GtkWidget *alignment1;
  GtkWidget *hbox2;
  GtkWidget *image1;
  GtkWidget *label5;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
  static void on_button_portion_order_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_portion_order ();
  virtual void gui_reorder_include ();
private:
  Scripture * scripture;
  Configuration * configuration;
};


#endif

==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/dialogprintproject.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGPRINTPROJECT_H
#define INCLUDED_DIALOGPRINTPROJECT_H


#include <gtk/gtk.h>
#include "ustring.h"


class PrintProjectDialog
{
public:
  PrintProjectDialog (int dummy);
  ~PrintProjectDialog ();
  int run ();
protected:
  GtkWidget *printprojectdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *hbox1;
  GtkWidget *label1;
  GtkWidget *label_portion;
  GtkWidget *vseparator1;
  GtkWidget *label3;
  GtkWidget *label_order;
  GtkWidget *vseparator2;
  GtkWidget *button_portion_order;
  GtkWidget *alignment1;
  GtkWidget *hbox2;
  GtkWidget *image1;
  GtkWidget *label5;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  void on_okbutton ();
  static void on_button_portion_order_clicked (GtkButton *button, gpointer user_data);
  void on_button_portion_order ();
  void gui_reorder_include ();
};


#endif
